@@ -19,6 +19,10 @@ class DecomposedMatrix:
     def shape(self):
         return self.compressed.shape[0], self.components.shape[1]
 
+    @property
+    def dtype(self):
+        return self.components.dtype
+
     @classmethod
     def compress(cls, data, n_components=30, fp16=True):
         if not TruncatedSVD:
@@ -28,3 +32,6 @@ class DecomposedMatrix:
         if fp16:
             compressed = compressed.astype(np.float16)
         return cls(compressed, model.components_)
+
+    def __len__(self):
+        return len(self.compressed)
